@@ -370,7 +370,6 @@ QString KCalendarCore::ICalFormat::toString(const KCalendarCore::Duration &durat
 
 bool ICalFormat::fromString(RecurrenceRule *recurrence, const QString &rrule)
 {
-    Q_D(ICalFormat);
     if (!recurrence) {
         return false;
     }
@@ -383,7 +382,7 @@ bool ICalFormat::fromString(RecurrenceRule *recurrence, const QString &rrule)
     }
 
     if (success) {
-        d->mImpl.readRecurrence(recur, recurrence);
+        ICalFormatImpl::readRecurrence(recur, recurrence);
     }
 
     return success;
@@ -391,14 +390,13 @@ bool ICalFormat::fromString(RecurrenceRule *recurrence, const QString &rrule)
 
 Duration ICalFormat::durationFromString(const QString &duration) const
 {
-    Q_D(const ICalFormat);
     icalerror_clear_errno();
     const auto icalDuration = icaldurationtype_from_string(duration.toUtf8().constData());
     if (icalerrno != ICAL_NO_ERROR) {
         qCDebug(KCALCORE_LOG) << "Duration parsing error:" << icalerror_strerror(icalerrno);
         return {};
     }
-    return d->mImpl.readICalDuration(icalDuration);
+    return ICalFormatImpl::readICalDuration(icalDuration);
 }
 
 QString ICalFormat::createScheduleMessage(const IncidenceBase::Ptr &incidence, iTIPMethod method)
@@ -547,38 +545,7 @@ ScheduleMessage::Ptr ICalFormat::parseScheduleMessage(const Calendar::Ptr &cal,
     }
 
     icalproperty_method icalmethod = icalproperty_get_method(m);
-    iTIPMethod method;
-
-    switch (icalmethod) {
-    case ICAL_METHOD_PUBLISH:
-        method = iTIPPublish;
-        break;
-    case ICAL_METHOD_REQUEST:
-        method = iTIPRequest;
-        break;
-    case ICAL_METHOD_REFRESH:
-        method = iTIPRefresh;
-        break;
-    case ICAL_METHOD_CANCEL:
-        method = iTIPCancel;
-        break;
-    case ICAL_METHOD_ADD:
-        method = iTIPAdd;
-        break;
-    case ICAL_METHOD_REPLY:
-        method = iTIPReply;
-        break;
-    case ICAL_METHOD_COUNTER:
-        method = iTIPCounter;
-        break;
-    case ICAL_METHOD_DECLINECOUNTER:
-        method = iTIPDeclineCounter;
-        break;
-    default:
-        method = iTIPNoMethod;
-        qCDebug(KCALCORE_LOG) << "Unknown method";
-        break;
-    }
+    iTIPMethod method = ICalFormatImpl::fromIcalEnum(icalmethod);
 
     if (!icalrestriction_check(message)) {
         qCWarning(KCALCORE_LOG) << "\nkcalcore library reported a problem while parsing:";
